@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import abc
 import atexit
 import contextlib
@@ -103,10 +105,6 @@ def local_context(
         evaluation_context.reset(token)
 
 
-def _sigint_handler(sig, frame):
-    raise KeyboardInterrupt()
-
-
 @_cdata_res_to_rinterface
 def parse(text: str, num: int = -1):
     """Parse a string as R code.
@@ -233,8 +231,27 @@ def evalr(
     return res
 
 
-def vector_memoryview(obj: sexp.SexpVector,
-                      sizeof_str: str, cast_str: str) -> memoryview:
+@typing.overload
+def vector_memoryview(
+        obj: sexp.SexpVector,
+        sizeof_str: str,
+        cast_str: typing.Literal['i']
+) -> memoryview[int]: ...
+
+
+@typing.overload
+def vector_memoryview(
+        obj: sexp.SexpVector,
+        sizeof_str: str,
+        cast_str: typing.Literal['d']
+) -> memoryview[float]: ...
+
+
+def vector_memoryview(
+        obj: sexp.SexpVector,
+        sizeof_str: str,
+        cast_str: typing.Literal['i', 'd']
+) -> typing.Union[memoryview[int], memoryview[float]]:
     """
     :param obj: R vector
     :param str sizeof_str: Type in a string to use with ffi.sizeof()
@@ -524,7 +541,7 @@ class BoolSexpVector(SexpVectorWithNumpyInterface):
             raise TypeError(
                 'Indices must be integers or slices, not %s' % type(i))
 
-    def memoryview(self) -> memoryview:
+    def memoryview(self) -> memoryview[int]:
         return vector_memoryview(self, 'int', 'i')
 
 
@@ -578,7 +595,7 @@ class IntSexpVector(SexpVectorWithNumpyInterface):
             raise TypeError(
                 'Indices must be integers or slices, not %s' % type(i))
 
-    def memoryview(self) -> memoryview:
+    def memoryview(self) -> memoryview[int]:
         return vector_memoryview(self, 'int', 'i')
 
 
@@ -624,7 +641,7 @@ class FloatSexpVector(SexpVectorWithNumpyInterface):
             raise TypeError(
                 'Indices must be integers or slices, not %s' % type(i))
 
-    def memoryview(self) -> memoryview:
+    def memoryview(self) -> memoryview[float]:
         return vector_memoryview(self, 'double', 'd')
 
 
@@ -1132,7 +1149,7 @@ def _getrenvvars(
         os.path.join(r_home, 'bin', 'Rscript'),
         '-e',
         'x<-Sys.getenv();y<-as.character(x);names(y)<-names(x);'
-        'write.table(y,col.names=FALSE,quote=TRUE,sep=",")'
+        'write.csv(y)'
     )
 
     envvars = subprocess.check_output(cmd,
@@ -1141,6 +1158,8 @@ def _getrenvvars(
 
     res = []
     reader = csv.reader(row for row in envvars.split(os.linesep) if row != '')
+    # Skip column names.
+    next(reader)
     for k, v in reader:
         if (
                 (k not in baselinevars)
@@ -1216,7 +1235,7 @@ def _post_initr_setup() -> None:
     warn_about_thread = False
     if threading.current_thread() is threading.main_thread():
         try:
-            signal.signal(signal.SIGINT, _sigint_handler)
+            signal.signal(signal.SIGINT, signal.default_int_handler)
         except ValueError as ve:
             if str(ve) == 'signal only works in main thread':
                 warn_about_thread = True
